% function SHADE = get_shade(I, data, smooth_edge, weights)
%
% Syntax:
%   SHADE = get_shade(I, data, smooth_edge, weights) or
%   SHADE = get_shade(I, data, smooth_edge)
%
% Description:
%   generate shapes of objects using given data and weight information.   
% 
% Input:
%   I:              input image
%   data:           Structure of input image. Can be generated by calling shape_from_shading function. It contains the
%                   following fields
%                       data.A
%                       data.Dw
%                       data.sI
%                       data.MASK
%
%   smooth_edge:    whether to smooth the edge of shape. 1 is to smooth and 0 is not. By default, it is 1.
%   weights:        weights information of image. Its default values are 
%                       weights.BL    = 10;
%                       weights.Prec  = 0;
%                       weights.sm    = 10;
%                       weights.maxit = 2000;
%    
% Output:
%   SHADE:   result of shade estimated.
% 
% 
% This computer code is subject to copyright: (c) National ICT Australia Limited (NICTA) 2014 All Rights Reserved.
% Author: Ran Wei and Lin Gu

function SHADE = get_shade(I, data, smooth_edge, weights)

    switch nargin
        case 4
            SHADE = get_shade_(I, data, smooth_edge, weights);
        case 3
            SHADE = get_shade_(I, data, smooth_edge);
        case 2
            SHADE = get_shade_(I, data);
        otherwise
            error('Incorrect inputs. Please check');
    end
end