%   function [G, ...
%             K, ...
%             S, ...
%             dich_error, ...
%             smooth_error, ...
%             is_valid] = patch_dichromatic_decompose(I, ...
%                                                     L, ...
%                                                     alpha, ...
%                                                     debug)
%   This function is used to estimate g, k and S for a patch. It also
%   returns whether this patch is recognised as a valid dichromatic patch.
%   Given the light spectrum (i.e. the optimised g, k and S have positive
%   values). If so this patch will be used to optimise L in the subsequent
%   step in each iteration of the algorithm in LightEst4. Otherwise the
%   patch will be rejected from the computation.
%
%   Input:
%       I:  height x width x band, the input patch.
%       L:  band x 1, the known light spectrum.
%           NOTE: L must have all positive components.
%       alpha: a variable controlling the error threshold
%       debug: whether to show debug information, default value is 0
%
%   Output:
%
%       G: the shading map - shading factor
%       K: the specularity map. - specular coefficient
%       S: the reflectance of the patch. - spectral reflectance
%       is_valid: whether the select patch has the dichromatic
%       effect (is_valid == 1)
%
% This computer code is subject to copyright: (c) National ICT Australia Limited (NICTA) 2014 All Rights Reserved.
% Author: Ran Wei

function [G, ...
          K, ...
          S, ...
          dich_error, ...
          smooth_error, ...
          is_valid] = patch_dichromatic_decompose(I, ...
                                                  L, ...
                                                  alpha, ...
                                                  debug)

    if nargin == 3
        debug = 0;
    elseif nargin > 4 || argin < 3
        error('Incorrect input argument number');
    end
    
    [G, ...
     K, ...
     S, ...
     dich_error, ...
     smooth_error, ...
     is_valid] = patch_dichromatic_decompose_(I, ...
                                              L, ...
                                              alpha, ...
                                              debug);

end
